// TchartDisplay.cpp : implementation file
//

#include "stdafx.h"
#include "StabilizationTeeChart.h"
#include "TchartDisplay.h"


#include "TeeChartDefines.h"
#include "axes.h"
#include "axis.h"
#include "aspect.h"
#include "series.h"
#include "Canvas.h"
#include "Pen.h"
#include "environment.h"
#include "brush.h"
#include "AxisLabels.h" ///\TODO temp!!
#include "Panel.h"
#include "SurfaceSeries.h"
#include "Legend.h" 
#include "LegendSymbol.h" 



// CTchartDisplay dialog

IMPLEMENT_DYNAMIC(CTchartDisplay, CDialog)

CTchartDisplay::CTchartDisplay(CWnd* pParent /*=NULL*/)
	: CDialog(CTchartDisplay::IDD, pParent)
{

}

CTchartDisplay::~CTchartDisplay()
{
}

void CTchartDisplay::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
}


BEGIN_MESSAGE_MAP(CTchartDisplay, CDialog)
	ON_WM_SIZE()
END_MESSAGE_MAP()


// CTchartDisplay message handlers

BOOL CTchartDisplay::OnInitDialog()
{
	CDialog::OnInitDialog();

	// TODO:  Add extra initialization here
	CRect clientRect;
	GetClientRect(clientRect);
	if (!m_Chart.Create("TChart", WS_CHILD | WS_VISIBLE, clientRect, this, IDC_TCHART1))
		EndDialog(-1);

	RunTest();

	return TRUE;  // return TRUE unless you set the focus to a control
	// EXCEPTION: OCX Property Pages should return FALSE
}
void CTchartDisplay::SetTest(TestType eTestType)
{
	m_CurrentTest = eTestType;
}
void CTchartDisplay::RunTest()
{
	test3D_Compact();
}

void CTchartDisplay::test3D_Compact()
{
	// Setting axes
	m_Chart.GetAspect().SetView3D(true);

	m_Chart.GetPanel().SetMarginUnits(1);//pixels
	m_Chart.GetPanel().SetMarginTop(30);
	m_Chart.GetPanel().SetMarginLeft(40);
	m_Chart.GetPanel().SetMarginRight(40);
	m_Chart.GetPanel().SetMarginBottom(20);

	m_Chart.GetAxis().GetLeft().SetAutomatic(false);
	m_Chart.GetAxis().GetLeft().SetVisible(false);
	m_Chart.GetAxis().GetLeft().SetMaximum(15);
	m_Chart.GetAxis().GetLeft().SetMinimum(0);
	m_Chart.GetAxis().GetLeft().SetVisible(false);

	m_Chart.GetAxis().GetBottom().SetAutomatic(false);
	m_Chart.GetAxis().GetBottom().SetVisible(false);
	m_Chart.GetAxis().GetBottom().SetMaximum(11);
	m_Chart.GetAxis().GetBottom().SetMinimum(1);
	m_Chart.GetAxis().GetBottom().SetVisible(true);

	m_Chart.GetAxis().GetDepth().SetMaximum(100);
	m_Chart.GetAxis().GetDepth().SetMinimum(0);
	m_Chart.GetAxis().GetDepth().SetVisible(true);
	m_Chart.GetAxis().GetDepth().SetOtherside(false);

	// Setting margins
	m_Chart.GetPanel().SetMarginLeft(300);
	m_Chart.GetPanel().SetMarginRight(200);

	m_Chart.AddSeries(scSurface);

	// Perspective and axes rotation
	m_Chart.GetAspect().SetOrthogonal(false);
	m_Chart.GetAspect().SetPerspective(0);
	m_Chart.GetAspect().SetOrthoAngle(0);
	m_Chart.GetAspect().SetElevation(270);// around horizontal axis  - Setting top view
	m_Chart.GetAspect().SetTilt(0);		// around depth axis
	m_Chart.GetAspect().SetRotation(0);	// around vertical axis
	m_Chart.GetAspect().SetChart3DPercent(100);


	m_Chart.Series(0).GetPen().SetColor(RGB(0,255,255));

	m_Chart.Series(0).GetAsSurface().GetBrush().SetStyle(0);
	m_Chart.Series(0).GetAsSurface().SetNumZValues(12); 
	m_Chart.Series(0).GetAsSurface().SetNumXValues(11);

	m_Chart.GetEnvironment().InternalRepaint(); 

	// Painting all grid cell in grey
	for( int i= 1; i<11; i++)
	{
		for(int j = 2; j<13; j++)
			m_Chart.Series(0).GetAsSurface().AddXYZ(i, 0, j,"",RGB(109, 112, 121));
	}


	// Setting color palette
	m_Chart.Series(0).GetAsSurface().SetPaletteStyle(psCustom);
	m_Chart.Series(0).GetAsSurface().SetUsePalette(true);
	m_Chart.Series(0).GetAsSurface().ClearPalette();
	m_Chart.Series(0).GetAsSurface().AddPalette(1, RGB(0, 00, 0));
	m_Chart.Series(0).GetAsSurface().AddPalette(11, RGB(255, 0, 0));
	m_Chart.Series(0).GetAsSurface().AddPalette(21, RGB(0, 255, 0));
	m_Chart.Series(0).GetAsSurface().AddPalette(31, RGB(0, 0, 255));

	// Painting some grid cells
	m_Chart.Series(0).GetAsSurface().AddXYZ(1, 0, 2,"",m_Chart.Series(0).GetAsSurface().GetSurfacePaletteColor(30));
	m_Chart.Series(0).GetAsSurface().AddXYZ(2, 0, 3,"",m_Chart.Series(0).GetAsSurface().GetSurfacePaletteColor(10));
	m_Chart.Series(0).GetAsSurface().AddXYZ(3, 0, 4,"",m_Chart.Series(0).GetAsSurface().GetSurfacePaletteColor(20));
	m_Chart.Series(0).GetAsSurface().AddXYZ(4, 0, 5,"",m_Chart.Series(0).GetAsSurface().GetSurfacePaletteColor(30));

	m_Chart.GetLegend().GetSymbol().SetSquared(true);

	m_Chart.Repaint();
}

void CTchartDisplay::OnSize(UINT nType, int cx, int cy)
{
	CDialog::OnSize(nType, cx, cy);

	// TODO: Add your message handler code here
	if (m_Chart.m_hWnd != NULL)
		m_Chart.MoveWindow(0, 0, cx, cy);
}
BEGIN_EVENTSINK_MAP(CTchartDisplay, CDialog)
	ON_EVENT(CTchartDisplay, IDC_TCHART1, 1, CTchartDisplay::OnAfterDrawTchart1, VTS_NONE)
END_EVENTSINK_MAP()

void CTchartDisplay::OnAfterDrawTchart1()
{
	// Draw an rotated ellipse in a plane parallel to the XY plane.
	// How to do it in a plane parallel to to the XZ plane?

	m_Chart.GetCanvas().GetPen().SetColor(RGB(255,0,0));
	m_Chart.GetCanvas().GetPen().SetWidth(2);

	long x1 = m_Chart.GetAxis().GetBottom().CalcXPosValue(4.0);
	long y1 = m_Chart.GetAxis().GetLeft().CalcYPosValue(5.0);
	long x2 = m_Chart.GetAxis().GetBottom().CalcXPosValue(6.0);
	long y2 = m_Chart.GetAxis().GetLeft().CalcYPosValue(7.0);

	m_Chart.GetCanvas().RotatedEllipse(x1,y1,x2,y2, 570, 60);

}
